@@ -21,7 +21,7 @@
 #include "JobQueue.h"
 
 #include "utils/Logger.h"
-#include "utils/YamlUtils.h"
+#include "utils/Yaml.h"
 
 #include <QFile>
 #include <QJsonDocument>
