@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2019, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -40,11 +40,6 @@ public:
     JobResult exec() override;
 
 private:
-    int callOutput( const QString& command,
-                    QString& output,
-                    const QString& workingPath = QString(),
-                    const QString& stdInput = QString(),
-                    int timeoutSec = 0 );
     QString m_command;
     QString m_workingPath;
     bool m_runInChroot;
