@@ -19,7 +19,7 @@
 
 #include "PythonHelper.h"
 
-#include "utils/CalamaresUtils.h"
+#include "utils/Dirs.h"
 #include "utils/Logger.h"
 
 #include <QDir>
