@@ -54,6 +54,41 @@ ViewManager::instance( QObject* parent )
     return s_instance;
 }
 
+/** @brief Get a button-sized icon. */
+static inline QPixmap
+getButtonIcon( const QString& name )
+{
+    return Calamares::Branding::instance()->image( name, QSize( 22, 22 ) );
+}
+
+static inline void
+setButtonIcon( QPushButton* button, const QString& name )
+{
+    auto icon = getButtonIcon( name );
+    if ( button && !icon.isNull() )
+    {
+        button->setIcon( icon );
+    }
+}
+
+/** @brief Creates a button with a given icon-name
+ *
+ * Creates a new button as child of @p parent.
+ * Sets the named icon, if it exists, onto the button.
+ * Returns the new button.
+ *
+ * There is a QPushButton constructor that takes an icon,
+ * but it also needs a text and we've got translations
+ * to worry about as well as state.
+ */
+static inline QPushButton*
+makeButton( QWidget* parent, const QString& name )
+{
+    QPushButton* button = new QPushButton( parent );
+    setButtonIcon( button, name );
+    return button;
+}
+
 ViewManager::ViewManager( QObject* parent )
     : QObject( parent )
     , m_currentStep( 0 )
@@ -68,18 +103,13 @@ ViewManager::ViewManager( QObject* parent )
     m_stack->setContentsMargins( 0, 0, 0, 0 );
     mainLayout->addWidget( m_stack );
 
-    m_back = new QPushButton( m_widget );
-    m_next = new QPushButton( m_widget );
-    m_quit = new QPushButton( m_widget );
+    // Create buttons and sets an initial icon; the icons may change
+    m_back = makeButton( m_widget, "go-previous" );
+    m_next = makeButton( m_widget, "go-next" );
+    m_quit = makeButton( m_widget, "dialog-cancel" );
 
     CALAMARES_RETRANSLATE(
-        m_back->setText( tr( "&Back" ) );
-        m_next->setText( tr( "&Next" ) );
-        m_quit->setText( tr( "&Cancel" ) );
-        QString tooltip = Calamares::Settings::instance()->isSetupMode()
-            ? tr( "Cancel setup without changing the system." )
-            : tr( "Cancel installation without changing the system." );
-        m_quit->setToolTip( tooltip );
+        updateButtonLabels();
     )
 
     QBoxLayout* bottomLayout = new QHBoxLayout;
@@ -227,10 +257,18 @@ ViewManager::currentStepIndex() const
     return m_currentStep;
 }
 
+/** @brief Is the given step at @p index an execution step?
+ *
+ * Returns true if the step is an execution step, false otherwise.
+ * Also returns false if the @p index is out of range.
+ */
 static inline bool
-stepNextWillExecute(const ViewStepList& steps, int index)
+stepIsExecute( const ViewStepList& steps, int index )
 {
-    return ( index + 1 < steps.count() ) && qobject_cast< ExecutionViewStep* >( steps.at( index + 1 ) );
+    return
+        ( 0 <= index ) &&
+        ( index < steps.count() ) &&
+        ( qobject_cast< ExecutionViewStep* >( steps.at( index ) ) != nullptr );
 }
 
 void
@@ -241,11 +279,11 @@ ViewManager::next()
     if ( step->isAtEnd() )
     {
         const auto* const settings = Calamares::Settings::instance();
-        
+
         // Special case when the user clicks next on the very last page in a view phase
         // and right before switching to an execution phase.
         // Depending on Calamares::Settings, we show an "are you sure" prompt or not.
-        if ( settings->showPromptBeforeExecution() && stepNextWillExecute( m_steps, m_currentStep ) )
+        if ( settings->showPromptBeforeExecution() && stepIsExecute( m_steps, m_currentStep+1 ) )
         {
             QString title = settings->isSetupMode()
                 ? tr( "Continue with setup?" )
@@ -275,27 +313,35 @@ ViewManager::next()
         }
 
         m_currentStep++;
-        m_stack->setCurrentIndex( m_currentStep );
+
+        m_stack->setCurrentIndex( m_currentStep );  // Does nothing if out of range
         step->onLeave();
-        m_steps.at( m_currentStep )->onActivate();
-        executing = qobject_cast< ExecutionViewStep* >( m_steps.at( m_currentStep ) ) != nullptr;
-        emit currentStepChanged();
-        if ( executing )
+
+        if ( m_currentStep < m_steps.count() )
         {
-            m_back->setEnabled( false );
-            m_next->setEnabled( false );
-            // Enabled if there's nothing blocking it during exec
-            m_quit->setEnabled( !( settings->dontCancel() || settings->disableCancel() ) );
+            m_steps.at( m_currentStep )->onActivate();
+            executing = qobject_cast< ExecutionViewStep* >( m_steps.at( m_currentStep ) ) != nullptr;
+            emit currentStepChanged();
         }
         else
-            // Enabled unless it's also hidden
-            m_quit->setEnabled( !settings->disableCancel() );
+        {
+            // Reached the end in a weird state (e.g. no finished step after an exec)
+            executing = false;
+            m_next->setEnabled( false );
+            m_back->setEnabled( false );
+        }
+        updateCancelEnabled( !settings->disableCancel() && !(executing && settings->disableCancelDuringExec() ) );
     }
     else
+    {
         step->next();
+    }
 
-    m_next->setEnabled( !executing && m_steps.at( m_currentStep )->isNextEnabled() );
-    m_back->setEnabled( !executing && m_steps.at( m_currentStep )->isBackEnabled() );
+    if ( m_currentStep < m_steps.count() )
+    {
+        m_next->setEnabled( !executing && m_steps.at( m_currentStep )->isNextEnabled() );
+        m_back->setEnabled( !executing && m_steps.at( m_currentStep )->isBackEnabled() );
+    }
 
     updateButtonLabels();
 }
@@ -303,37 +349,51 @@ ViewManager::next()
 void
 ViewManager::updateButtonLabels()
 {
-    QString next = Calamares::Settings::instance()->isSetupMode()
+    const auto* const settings = Calamares::Settings::instance();
+
+    QString nextIsInstallationStep = settings->isSetupMode()
         ? tr( "&Set up" )
         : tr( "&Install" );
-    QString complete = Calamares::Settings::instance()->isSetupMode()
+    QString quitOnCompleteTooltip = settings->isSetupMode()
         ? tr( "Setup is complete. Close the setup program." )
         : tr( "The installation is complete. Close the installer." );
-    QString quit = Calamares::Settings::instance()->isSetupMode()
+    QString cancelBeforeInstallationTooltip = settings->isSetupMode()
         ? tr( "Cancel setup without changing the system." )
         : tr( "Cancel installation without changing the system." );
 
-    if ( stepNextWillExecute( m_steps, m_currentStep ) )
-        m_next->setText( next );
-    else
-        m_next->setText( tr( "&Next" ) );
-
-    if ( m_currentStep == m_steps.count() -1 && m_steps.last()->isAtEnd() )
+    // If we're going into the execution step / install phase, other message
+    if ( stepIsExecute( m_steps, m_currentStep+1 ) )
     {
-        m_quit->setText( tr( "&Done" ) );
-        m_quit->setToolTip( complete );
-        m_quit->setVisible( true );  // At end, always visible and enabled.
-        m_quit->setEnabled( true );
+        m_next->setText( nextIsInstallationStep );
+        setButtonIcon( m_next, "run-install" );
     }
     else
     {
-        if ( Calamares::Settings::instance()->disableCancel() )
-        {
-            m_quit->setVisible( false );
-            m_quit->setEnabled( false );  // Can't be triggered through DBUS
-        }
+        m_next->setText( tr( "&Next" ) );
+        setButtonIcon( m_next, "go-next" );
+    }
+
+    // Going back is always simple
+    m_back->setText( tr( "&Back" ) );
+
+    // Cancel button changes label at the end
+    if ( isAtVeryEnd() )
+    {
+        m_quit->setText( tr( "&Done" ) );
+        m_quit->setToolTip( quitOnCompleteTooltip );
+        m_quit->setVisible( true );  // At end, always visible and enabled.
+        setButtonIcon( m_quit, "dialog-ok-apply" );
+        updateCancelEnabled( true );
+    }
+    else
+    {
+        if ( settings->disableCancel() )
+            m_quit->setVisible( false );  // In case we went back from final
+        updateCancelEnabled( !settings->disableCancel() && !( stepIsExecute( m_steps, m_currentStep ) && settings->disableCancelDuringExec() ) );
+
         m_quit->setText( tr( "&Cancel" ) );
-        m_quit->setToolTip( quit );
+        m_quit->setToolTip( cancelBeforeInstallationTooltip );
+        setButtonIcon( m_quit, "dialog-cancel" );
     }
 }
 
@@ -364,31 +424,44 @@ ViewManager::back()
 
 bool ViewManager::confirmCancelInstallation()
 {
-    // If it's NOT the last page of the last step, we ask for confirmation
-    if ( !( m_currentStep == m_steps.count() -1 &&
-            m_steps.last()->isAtEnd() ) )
-    {
-        QString title = Calamares::Settings::instance()->isSetupMode()
-            ? tr( "Cancel setup?" )
-            : tr( "Cancel installation?" );
-        QString question = Calamares::Settings::instance()->isSetupMode()
-            ? tr( "Do you really want to cancel the current setup process?\n"
-                  "The setup program will quit and all changes will be lost." )
-            : tr( "Do you really want to cancel the current install process?\n"
-                  "The installer will quit and all changes will be lost." );
-        QMessageBox mb( QMessageBox::Question,
-                        title,
-                        question,
-                        QMessageBox::Yes | QMessageBox::No,
-                        m_widget );
-        mb.setDefaultButton( QMessageBox::No );
-        mb.button( QMessageBox::Yes )->setText( tr( "&Yes" ) );
-        mb.button( QMessageBox::No )->setText( tr( "&No" ) );
-        int response = mb.exec();
-        return response == QMessageBox::Yes;
-    }
-    else // Means we're at the end, no need to confirm.
+    const auto* const settings = Calamares::Settings::instance();
+
+    // When we're at the very end, then it's always OK to exit.
+    if ( isAtVeryEnd() )
         return true;
+
+    // Not at the very end, cancel/quit might be disabled
+    if ( settings->disableCancel() )
+        return false;
+    if ( settings->disableCancelDuringExec() && stepIsExecute( m_steps, m_currentStep ) )
+        return false;
+
+    // Otherwise, confirm cancel/quit.
+    QString title = settings->isSetupMode()
+        ? tr( "Cancel setup?" )
+        : tr( "Cancel installation?" );
+    QString question = settings->isSetupMode()
+        ? tr( "Do you really want to cancel the current setup process?\n"
+                "The setup program will quit and all changes will be lost." )
+        : tr( "Do you really want to cancel the current install process?\n"
+                "The installer will quit and all changes will be lost." );
+    QMessageBox mb( QMessageBox::Question,
+                    title,
+                    question,
+                    QMessageBox::Yes | QMessageBox::No,
+                    m_widget );
+    mb.setDefaultButton( QMessageBox::No );
+    mb.button( QMessageBox::Yes )->setText( tr( "&Yes" ) );
+    mb.button( QMessageBox::No )->setText( tr( "&No" ) );
+    int response = mb.exec();
+    return response == QMessageBox::Yes;
+}
+
+void
+ViewManager::updateCancelEnabled( bool enabled )
+{
+    m_quit->setEnabled( enabled );
+    emit cancelEnabled( enabled );
 }
 
 }  // namespace
