@@ -19,27 +19,28 @@
 
 #include "CppJobModule.h"
 
-#include "utils/PluginFactory.h"
-#include "utils/Logger.h"
 #include "CppJob.h"
+#include "utils/Logger.h"
+#include "utils/PluginFactory.h"
 
 #include <QDir>
 #include <QPluginLoader>
 
-namespace Calamares {
+namespace Calamares
+{
 
 
 Module::Type
 CppJobModule::type() const
 {
-    return Job;
+    return Module::Type::Job;
 }
 
 
 Module::Interface
 CppJobModule::interface() const
 {
-    return QtPluginInterface;
+    return Module::Interface::QtPlugin;
 }
 
 
@@ -55,20 +56,20 @@ CppJobModule::loadSelf()
             return;
         }
 
-        CppJob *cppJob = pf->create< Calamares::CppJob >();
+        CppJob* cppJob = pf->create< Calamares::CppJob >();
         if ( !cppJob )
         {
             cDebug() << Q_FUNC_INFO << m_loader->errorString();
             return;
         }
-//        cDebug() << "CppJobModule loading self for instance" << instanceKey()
-//                 << "\nCppJobModule at address" << this
-//                 << "\nCalamares::PluginFactory at address" << pf
-//                 << "\nCppJob at address" << cppJob;
+        //        cDebug() << "CppJobModule loading self for instance" << instanceKey()
+        //                 << "\nCppJobModule at address" << this
+        //                 << "\nCalamares::PluginFactory at address" << pf
+        //                 << "\nCppJob at address" << cppJob;
 
         cppJob->setModuleInstanceKey( instanceKey() );
         cppJob->setConfigurationMap( m_configurationMap );
-        m_job = Calamares::job_ptr( static_cast< Calamares::Job * >( cppJob ) );
+        m_job = Calamares::job_ptr( static_cast< Calamares::Job* >( cppJob ) );
         m_loaded = true;
         cDebug() << "CppJobModule" << instanceKey() << "loading complete.";
     }
@@ -96,7 +97,7 @@ CppJobModule::initFrom( const QVariantMap& moduleDescriptor )
     // If a load path is not specified, we look for a plugin to load in the directory.
     if ( load.isEmpty() || !QLibrary::isLibrary( load ) )
     {
-        const QStringList ls = directory.entryList( QStringList{ "*.so" } );
+        const QStringList ls = directory.entryList( QStringList { "*.so" } );
         if ( !ls.isEmpty() )
         {
             for ( QString entry : ls )
@@ -125,4 +126,4 @@ CppJobModule::~CppJobModule()
     delete m_loader;
 }
 
-} // namespace Calamares
+}  // namespace Calamares
