@@ -21,7 +21,6 @@
 #define MODULELOADER_H
 
 #include "Requirement.h"
-#include "Typedefs.h"
 
 #include <QObject>
 #include <QStringList>
@@ -92,7 +91,7 @@ public:
 signals:
     void initDone();
     void modulesLoaded();  /// All of the modules were loaded successfully
-    void modulesFailed( QStringList );   /// .. or not
+    void modulesFailed( QStringList );  /// .. or not
     // Below, see RequirementsChecker documentation
     void requirementsComplete( bool );
     void requirementsResult( RequirementsList );
@@ -130,6 +129,6 @@ private:
     static ModuleManager* s_instance;
 };
 
-}
+}  // namespace Calamares
 
-#endif // MODULELOADER_H
+#endif  // MODULELOADER_H
