@@ -16,7 +16,7 @@ class QJsonModel : public QAbstractItemModel
 {
     Q_OBJECT
 public:
-    explicit QJsonModel(QObject *parent = 0);
+    explicit QJsonModel(QObject *parent = nullptr);
     ~QJsonModel();
     bool load(const QString& fileName);
     bool load(QIODevice * device);
