@@ -43,7 +43,7 @@ FixedAspectRatioLabel::setPixmap( const QPixmap& pixmap )
 void
 FixedAspectRatioLabel::resizeEvent( QResizeEvent* event )
 {
-    Q_UNUSED( event );
+    Q_UNUSED( event )
     QLabel::setPixmap( m_pixmap.scaled(
                            contentsRect().size(),
                            Qt::KeepAspectRatio,
