@@ -20,7 +20,7 @@
 #include "ContextualProcessJob.h"
 
 #include "utils/CommandList.h"
-#include "utils/YamlUtils.h"
+#include "utils/Yaml.h"
 
 #include <QtTest/QtTest>
 
