@@ -31,7 +31,7 @@ public:
     explicit LocaleConfiguration();
     /// @brief Create a locale with everything set to the given @p localeName
     explicit LocaleConfiguration( const QString& localeName /* "en_US.UTF-8" */ )
-        : LocaleConfiguration( localeName, localeName ) { };
+        : LocaleConfiguration( localeName, localeName ) { }
     /// @brief Create a locale with language and formats separate
     explicit LocaleConfiguration( const QString& localeName, const QString& formatsName );
 
