@@ -20,9 +20,8 @@
 #ifndef LOCALEPAGE_H
 #define LOCALEPAGE_H
 
-#include "Typedefs.h"
-
 #include "LocaleConfiguration.h"
+#include "Job.h"
 
 #include <QWidget>
 
@@ -44,7 +43,7 @@ public:
 
     QString prettyStatus() const;
 
-    QList< Calamares::job_ptr > createJobs();
+    Calamares::JobList createJobs();
 
     QMap< QString, QString > localesMap();
 
@@ -52,7 +51,6 @@ public:
 
 private:
     LocaleConfiguration guessLocaleConfiguration() const;
-    QString prettyLCLocale( const QString& localesMap ) const;
 
     // For the given locale config, return two strings describing
     // the settings for language and numbers.
