@@ -6,6 +6,7 @@
 #   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
 #   Copyright 2017, Alf Gaida <agaida@siduction.org>
 #   Copyright 2019, Adriaan de Groot <groot@kde.org>
+#   Copyright 2019, Kevin Kofler <kevin.kofler@chello.at>
 #
 #   Calamares is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -22,6 +23,7 @@
 
 import tempfile
 import subprocess
+import os
 
 import libcalamares
 
@@ -48,7 +50,15 @@ def mount_partitions(root_mount_point, partitions):
             continue
         # Create mount point with `+` rather than `os.path.join()` because
         # `partition["mountPoint"]` starts with a '/'.
-        mount_point = root_mount_point + partition["mountPoint"]
+        raw_mount_point = partition["mountPoint"]
+        mount_point = root_mount_point + raw_mount_point
+
+        # Ensure that the created directory has the correct SELinux context on
+        # SELinux-enabled systems.
+        os.makedirs(mount_point, exist_ok=True)
+        subprocess.call(['chcon', '--reference=' + raw_mount_point,
+                         mount_point])
+
         fstype = partition.get("fs", "").lower()
 
         if fstype == "fat16" or fstype == "fat32":
@@ -133,9 +143,15 @@ def run():
 
     :return:
     """
-    root_mount_point = tempfile.mkdtemp(prefix="calamares-root-")
     partitions = libcalamares.globalstorage.value("partitions")
 
+    if not partitions:
+        libcalamares.utils.warning("partitions is empty, {!s}".format(partitions))
+        return (_("Configuration Error"),
+                _("No partitions are defined for <pre>{!s}</pre> to use." ).format("mount"))
+
+    root_mount_point = tempfile.mkdtemp(prefix="calamares-root-")
+
     # Guard against missing keys (generally a sign that the config file is bad)
     extra_mounts = libcalamares.job.configuration.get("extraMounts") or []
     extra_mounts_efi = libcalamares.job.configuration.get("extraMountsEfi") or []
