@@ -43,216 +43,6 @@
 namespace PartUtils
 {
 
-static const NamedEnumTable<SizeUnit>&
-unitSuffixes()
-{
-    static const NamedEnumTable<SizeUnit> names{
-        { QStringLiteral( "%" ), SizeUnit::Percent },
-        { QStringLiteral( "B" ), SizeUnit::Byte },
-        { QStringLiteral( "K" ), SizeUnit::KiB },
-        { QStringLiteral( "M" ), SizeUnit::MiB },
-        { QStringLiteral( "G" ), SizeUnit::GiB }
-    };
-
-    return names;
-}
-
-PartSize::PartSize( const QString& s )
-    : NamedSuffix( unitSuffixes(), s )
-{
-    if ( ( unit() == SizeUnit::Percent ) && ( value() > 100 || value() < 0 ) )
-    {
-        cDebug() << "Percent value" << value() << "is not valid.";
-        m_value = 0;
-    }
-
-    if ( m_unit == SizeUnit::None )
-    {
-        m_value = s.toInt();
-        if ( m_value > 0 )
-            m_unit = SizeUnit::Byte;
-    }
-
-    if ( m_value <= 0 )
-    {
-        m_value = 0;
-        m_unit = SizeUnit::None;
-    }
-}
-
-qint64
-PartSize::toSectors( qint64 totalSectors, qint64 sectorSize ) const
-{
-    if ( !isValid() )
-        return -1;
-    if ( totalSectors < 1 || sectorSize < 1 )
-        return -1;
-
-    switch ( m_unit )
-    {
-    case unit_t::None:
-        return -1;
-    case unit_t::Percent:
-        if ( value() == 100 )
-            return totalSectors;  // Common-case, avoid futzing around
-        else
-            return totalSectors * value() / 100;
-    case unit_t::Byte:
-    case unit_t::KiB:
-    case unit_t::MiB:
-    case unit_t::GiB:
-        return bytesToSectors ( toBytes(), sectorSize );
-    }
-
-    return -1;
-}
-
-qint64
-PartSize::toBytes( qint64 totalSectors, qint64 sectorSize ) const
-{
-    if ( !isValid() )
-        return -1;
-
-    switch ( m_unit )
-    {
-    case unit_t::None:
-        return -1;
-    case unit_t::Percent:
-        if ( totalSectors < 1 || sectorSize < 1 )
-            return -1;
-        if ( value() == 100 )
-            return totalSectors * sectorSize;  // Common-case, avoid futzing around
-        else
-            return totalSectors * value() / 100;
-    case unit_t::Byte:
-    case unit_t::KiB:
-    case unit_t::MiB:
-    case unit_t::GiB:
-        return toBytes();
-    }
-
-    // notreached
-    return -1;
-}
-
-qint64
-PartSize::toBytes( qint64 totalBytes ) const
-{
-    if ( !isValid() )
-        return -1;
-
-    switch ( m_unit )
-    {
-    case unit_t::None:
-        return -1;
-    case unit_t::Percent:
-        if ( totalBytes < 1 )
-            return -1;
-        if ( value() == 100 )
-            return totalBytes;  // Common-case, avoid futzing around
-        else
-            return totalBytes * value() / 100;
-    case unit_t::Byte:
-    case unit_t::KiB:
-    case unit_t::MiB:
-    case unit_t::GiB:
-        return toBytes();
-    }
-
-    // notreached
-    return -1;
-}
-
-qint64
-PartSize::toBytes() const
-{
-    if ( !isValid() )
-        return -1;
-
-    switch ( m_unit )
-    {
-    case unit_t::Byte:
-        return value();
-    case unit_t::KiB:
-        return CalamaresUtils::KiBtoBytes( static_cast<unsigned long long>( value() ) );
-    case unit_t::MiB:
-        return CalamaresUtils::MiBtoBytes( static_cast<unsigned long long>( value() ) );
-    case unit_t::GiB:
-        return CalamaresUtils::GiBtoBytes( static_cast<unsigned long long>( value() ) );
-    default:
-        break;
-    }
-
-    // Reached only when unit is Percent or None
-    return -1;
-}
-
-bool
-PartSize::operator< ( const PartSize& other ) const
-{
-    if ( ( m_unit == SizeUnit::None || other.m_unit == SizeUnit::None ) ||
-         ( m_unit == SizeUnit::Percent && other.m_unit != SizeUnit::Percent ) ||
-         ( m_unit != SizeUnit::Percent && other.m_unit == SizeUnit::Percent ) )
-        return false;
-
-    switch ( m_unit )
-    {
-    case SizeUnit::Percent:
-        return ( m_value < other.m_value );
-    case SizeUnit::Byte:
-    case SizeUnit::KiB:
-    case SizeUnit::MiB:
-    case SizeUnit::GiB:
-        return ( toBytes() < other.toBytes () );
-    }
-
-    return false;
-}
-
-bool
-PartSize::operator> ( const PartSize& other ) const
-{
-    if ( ( m_unit == SizeUnit::None || other.m_unit == SizeUnit::None ) ||
-         ( m_unit == SizeUnit::Percent && other.m_unit != SizeUnit::Percent ) ||
-         ( m_unit != SizeUnit::Percent && other.m_unit == SizeUnit::Percent ) )
-        return false;
-
-    switch ( m_unit )
-    {
-    case SizeUnit::Percent:
-        return ( m_value > other.m_value );
-    case SizeUnit::Byte:
-    case SizeUnit::KiB:
-    case SizeUnit::MiB:
-    case SizeUnit::GiB:
-        return ( toBytes() > other.toBytes () );
-    }
-
-    return false;
-}
-
-bool
-PartSize::operator== ( const PartSize& other ) const
-{
-    if ( ( m_unit == SizeUnit::None || other.m_unit == SizeUnit::None ) ||
-         ( m_unit == SizeUnit::Percent && other.m_unit != SizeUnit::Percent ) ||
-         ( m_unit != SizeUnit::Percent && other.m_unit == SizeUnit::Percent ) )
-        return false;
-
-    switch ( m_unit )
-    {
-    case SizeUnit::Percent:
-        return ( m_value == other.m_value );
-    case SizeUnit::Byte:
-    case SizeUnit::KiB:
-    case SizeUnit::MiB:
-    case SizeUnit::GiB:
-        return ( toBytes() == other.toBytes () );
-    }
-
-    return false;
-}
-
 QString
 convenienceName( const Partition* const candidate )
 {
@@ -272,37 +62,55 @@ convenienceName( const Partition* const candidate )
     return p;
 }
 
+/** @brief Get the globalStorage setting for required space. */
+static double
+getRequiredStorageGiB( bool& ok )
+{
+    return Calamares::JobQueue::instance()->globalStorage()->value( "requiredStorageGiB" ).toDouble( &ok );
+}
+
 bool
 canBeReplaced( Partition* candidate )
 {
     if ( !candidate )
+    {
+        cDebug() << "Partition* is NULL";
         return false;
+    }
 
+    cDebug() << "Checking if" << convenienceName( candidate ) << "can be replaced.";
     if ( candidate->isMounted() )
+    {
+        cDebug() << Logger::SubEntry << "NO, it is mounted.";
         return false;
+    }
 
     bool ok = false;
-    double requiredStorageGB = Calamares::JobQueue::instance()
-                                    ->globalStorage()
-                                    ->value( "requiredStorageGB" )
-                                    .toDouble( &ok );
+    double requiredStorageGiB = getRequiredStorageGiB( ok );
+    if ( !ok )
+    {
+        cDebug() << Logger::SubEntry << "NO, requiredStorageGiB is not set correctly.";
+        return false;
+    }
 
     qint64 availableStorageB = candidate->capacity();
-    qint64 requiredStorageB = ( requiredStorageGB + 0.5 ) * 1024 * 1024 * 1024;
-    cDebug() << "Required  storage B:" << requiredStorageB
-             << QString( "(%1GB)" ).arg( requiredStorageB / 1024 / 1024 / 1024 );
-    cDebug() << "Storage capacity  B:" << availableStorageB
-             << QString( "(%1GB)" ).arg( availableStorageB / 1024 / 1024 / 1024 )
-             << "for" << convenienceName( candidate ) << "   length:" << candidate->length();
+    qint64 requiredStorageB = CalamaresUtils::GiBtoBytes( requiredStorageGiB + 0.5 );
 
-    if ( ok &&
-         availableStorageB > requiredStorageB )
+    if ( availableStorageB > requiredStorageB )
     {
         cDebug() << "Partition" << convenienceName( candidate ) << "authorized for replace install.";
-
         return true;
     }
-    return false;
+    else
+    {
+        Logger::CDebug deb;
+        deb << Logger::SubEntry << "NO, insufficient storage";
+        deb << Logger::Continuation << "Required  storage B:" << requiredStorageB
+                << QString( "(%1GiB)" ).arg( requiredStorageGiB );
+        deb << Logger::Continuation << "Available storage B:" << availableStorageB
+                << QString( "(%1GiB)" ).arg( CalamaresUtils::BytesToGiB( availableStorageB ) );
+        return false;
+    }
 }
 
 
@@ -354,40 +162,35 @@ canBeResized( Partition* candidate )
     }
 
     bool ok = false;
-    double requiredStorageGB = Calamares::JobQueue::instance()
-                                    ->globalStorage()
-                                    ->value( "requiredStorageGB" )
-                                    .toDouble( &ok );
+    double requiredStorageGiB = getRequiredStorageGiB( ok );
+    if ( !ok )
+    {
+        cDebug() << Logger::SubEntry << "NO, requiredStorageGiB is not set correctly.";
+        return false;
+    }
+
     // We require a little more for partitioning overhead and swap file
-    double advisedStorageGB = requiredStorageGB + 0.5 + 2.0;
+    double advisedStorageGiB = requiredStorageGiB + 0.5 + 2.0;
     qint64 availableStorageB = candidate->available();
+    qint64 advisedStorageB = CalamaresUtils::GiBtoBytes( advisedStorageGiB );
 
-    qint64 advisedStorageB = CalamaresUtils::GiBtoBytes( advisedStorageGB );
-
-    if ( ok &&
-         availableStorageB > advisedStorageB )
+    if ( availableStorageB > advisedStorageB )
     {
         cDebug() << "Partition" << convenienceName( candidate ) << "authorized for resize + autopartition install.";
-
         return true;
     }
-    else if ( ok )
+    else
     {
         Logger::CDebug deb;
         deb << Logger::SubEntry << "NO, insufficient storage";
         deb << Logger::Continuation << "Required  storage B:" << advisedStorageB
-                << QString( "(%1GB)" ).arg( advisedStorageGB );
+                << QString( "(%1GiB)" ).arg( advisedStorageGiB );
         deb << Logger::Continuation << "Available storage B:" << availableStorageB
-                << QString( "(%1GB)" ).arg( availableStorageB / 1024 / 1024 / 1024 )
+                << QString( "(%1GiB)" ).arg( CalamaresUtils::BytesToGiB( availableStorageB ) )
                 << "for" << convenienceName( candidate ) << "length:" << candidate->length()
                 << "sectorsUsed:" << candidate->sectorsUsed() << "fsType:" << candidate->fileSystem().name();
         return false;
     }
-    else
-    {
-        cDebug() << Logger::SubEntry << "NO, requiredStorageGB is not set correctly.";
-        return false;
-    }
 }
 
 
