@@ -33,16 +33,19 @@
 #include "gui/PartitionBarsView.h"
 #include "gui/PartitionLabelsView.h"
 
+#include "Branding.h"
 #include "CalamaresVersion.h"
+#include "GlobalStorage.h"
+#include "Job.h"
+#include "JobQueue.h"
+
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Logger.h"
 #include "utils/NamedEnum.h"
 #include "utils/Retranslator.h"
+#include "utils/Variant.h"
 #include "widgets/WaitingWidget.h"
-#include "GlobalStorage.h"
-#include "JobQueue.h"
-#include "Job.h"
-#include "Branding.h"
+
 
 #include <kpmcore/core/device.h>
 #include <kpmcore/core/partition.h>
@@ -66,6 +69,7 @@ PartitionViewStep::PartitionViewStep( QObject* parent )
     , m_widget( new QStackedWidget() )
     , m_choicePage( nullptr )
     , m_manualPartitionPage( nullptr )
+    , m_requiredStorageGiB( 0.0 )
 {
     m_widget->setContentsMargins( 0, 0, 0, 0 );
 
@@ -368,6 +372,14 @@ PartitionViewStep::isAtEnd() const
 void
 PartitionViewStep::onActivate()
 {
+    // If there's no setting (e.g. from the welcome page) for required storage
+    // then use ours, if it was set.
+    auto* gs = Calamares::JobQueue::instance() ? Calamares::JobQueue::instance()->globalStorage() : nullptr;
+    if ( m_requiredStorageGiB >= 0.0 && gs && !gs->contains( "requiredStorageGiB" ) )
+    {
+        gs->insert( "requiredStorageGiB", m_requiredStorageGiB );
+    }
+
     // if we're coming back to PVS from the next VS
     if ( m_widget->currentWidget() == m_choicePage &&
             m_choicePage->currentChoice() == ChoicePage::Alongside )
@@ -561,6 +573,9 @@ PartitionViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 
     m_swapChoices = choices;
 
+    // Settings that overlap with the Welcome module
+    m_requiredStorageGiB = CalamaresUtils::getDouble( configurationMap, "requiredStorage", -1.0 );
+
     // These gs settings seem to be unused (in upstream Calamares) outside of
     // the partition module itself.
     gs->insert( "ensureSuspendToDisk", ensureSuspendToDisk );
@@ -616,7 +631,7 @@ PartitionViewStep::setConfigurationMap( const QVariantMap& configurationMap )
 }
 
 
-QList< Calamares::job_ptr >
+Calamares::JobList
 PartitionViewStep::jobs() const
 {
     return m_core->jobs();
@@ -635,7 +650,11 @@ PartitionViewStep::checkRequirements()
         []{ return tr( "has at least one disk device available." ); },
         []{ return tr( "There are no partitons to install on." ); },
         m_core->deviceModel()->rowCount() > 0,  // satisfied
-        true    // required
+#ifdef DEBUG_PARTITION_UNSAFE
+             false  // optional
+#else
+             true   // required
+#endif
     } );
 
     return l;
