@@ -7,6 +7,7 @@
 #   Copyright 2014, Daniel Hillenbrand <codeworkx@bbqlinux.org>
 #   Copyright 2014, Philip Müller <philm@manjaro.org>
 #   Copyright 2017, Alf Gaida <agaida@siduction.org>
+#   Copyright 2019, Kevin Kofler <kevin.kofler@chello.at>
 #
 #   Calamares is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -252,13 +253,19 @@ class UnpackOperation:
             subprocess.check_call(["mount",
                                    "--bind", entry.source,
                                    imgmountdir])
-        else:
+        elif os.path.isfile(entry.source):
             subprocess.check_call(["mount",
                                    entry.source,
                                    imgmountdir,
                                    "-t", entry.sourcefs,
                                    "-o", "loop"
                                    ])
+        else: # entry.source is a device
+            subprocess.check_call(["mount",
+                                   entry.source,
+                                   imgmountdir,
+                                   "-t", entry.sourcefs
+                                   ])
 
     def unpack_image(self, entry, imgmountdir):
         """
